about summary refs log tree commit diff
path: root/sunrpc/rpc
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@redhat.com>1999-07-31 06:11:24 +0000
committerUlrich Drepper <drepper@redhat.com>1999-07-31 06:11:24 +0000
commitbdb04ee8e21c3ee229bf3d2ad2ca8288e3cb44e9 (patch)
treeefe99ba63e77cedcf730e424a1fcb0f5ef7a09ad /sunrpc/rpc
parent3d558f4ec7fecbac0dddb4d321a1ec10f14e8e03 (diff)
downloadglibc-bdb04ee8e21c3ee229bf3d2ad2ca8288e3cb44e9.tar.gz
glibc-bdb04ee8e21c3ee229bf3d2ad2ca8288e3cb44e9.tar.xz
glibc-bdb04ee8e21c3ee229bf3d2ad2ca8288e3cb44e9.zip
Update.
1999-07-30  Andreas Schwab  <schwab@suse.de>

	* sysdeps/unix/sysv/linux/getsysstats.c (GET_NPROCS_PARSER): New
	definition.
	(__get_nprocs): Use it.
	(__get_nprocs_conf): Define as separate function if
	GET_NPROCS_CONF_PARSER is defined.
	* sysdeps/unix/sysv/linux/alpha/getsysstats.c: New file.

	* include/sys/sysinfo.h: New file.
	* sysdeps/generic/sys/sysinfo.h: Remove declaration of internal
	interface.
	* sysdeps/unix/sysv/linux/sys/sysinfo.h: Likewise.

1999-07-30  H.J. Lu  <hjl@gnu.org>

	* libio/iofflush.c (fflush_unlocked): Weak aliase if
	_IO_MTSAFE_IO is not defined.
	* libio/clearerr.c (clearerr_unlocked): Likewise.
	* libio/feof.c (feof_unlocked): Likewise.
	* libio/ferror.c (ferror_unlocked): Likewise.
	* libio/fputc.c (fputc_unlocked): Likewise.
	* libio/getc.c (getc_unlocked, fgetc_unlocked): Likewise.
	* libio/getchar.c (getchar_unlocked): Likewise.
	* libio/putc.c (putc_unlocked): Likewise.
	* libio/putchar.c (putchar_unlocked): Likewise.

1999-07-30  Thorsten Kukuk  <kukuk@suse.de>

	* sunrpc/Versions: Add svc_getreq_common, svc_getreq_poll,
	  svc_max_pollfd and svc_pollfd to GLIBC_2.2
	* sunrpc/rpc/svc.h: Use rpc*_t types, add new prototypes
	  for svc_run/poll interface.
	* sunrpc/rpc/types.h: Add rpc*_t typedefs.
	* sunrpc/rpc_common.c: Add svc_pollfd and svc_max_pollfd as
	  global variable.
	* sunrpc/svc.c: Add svc_getreq_poll and svc_getreq_common,
	  rewrite other svc_getreq* functions to use svc_getreq_common.
	* sunrpc/svc_run.c: Use poll().

1999-07-30  Andreas Schwab  <schwab@suse.de>

	* Makerules: Put sysd-versions and Versions.all on
	postclean-generated instead of common-generated.

1999-07-29  Andreas Jaeger  <aj@arthur.rhein-neckar.de>

	* manual/time.texi (Basic CPU Time): Note that clock_t can wrap
	around and CLOCKS_PER_SEC is 1e6.
Diffstat (limited to 'sunrpc/rpc')
-rw-r--r--sunrpc/rpc/svc.h50
-rw-r--r--sunrpc/rpc/types.h9
2 files changed, 30 insertions, 29 deletions
diff --git a/sunrpc/rpc/types.h b/sunrpc/rpc/types.h
index 61ea3c19f8..e2e8402be9 100644
--- a/sunrpc/rpc/types.h
+++ b/sunrpc/rpc/types.h
@@ -1,4 +1,3 @@
-/* @(#)types.h	2.3 88/08/15 4.0 RPCSRC */
 /*
  * Sun RPC is a product of Sun Microsystems, Inc. and is provided for
  * unrestricted use provided that this legend is included on all tape
@@ -27,8 +26,6 @@
  * 2550 Garcia Avenue
  * Mountain View, California  94043
  */
-/*      @(#)types.h 1.18 87/07/24 SMI      */
-
 /* fixincludes should not add extern "C" to this file */
 /*
  * Rpc additions to <sys/types.h>
@@ -38,6 +35,12 @@
 
 typedef int bool_t;
 typedef int enum_t;
+/* This needs to be changed to uint32_t in the future */
+typedef unsigned long rpcprog_t;
+typedef unsigned long rpcvers_t;
+typedef unsigned long rpcproc_t;
+typedef unsigned long rpcprot_t;
+typedef unsigned long rpcport_t;
 
 #define        __dontcare__    -1
diff --git a/sunrpc/rpc/svc.h b/sunrpc/rpc/svc.h
index 4ac2a5cdf0..f607d6b659 100644
--- a/sunrpc/rpc/svc.h
+++ b/sunrpc/rpc/svc.h
@@ -1,4 +1,3 @@
-/* @(#)svc.h	2.2 88/07/29 4.0 RPCSRC; from 1.20 88/02/08 SMI */
 /*
  * Sun RPC is a product of Sun Microsystems, Inc. and is provided for
  * unrestricted use provided that this legend is included on all tape
@@ -147,12 +146,12 @@ struct SVCXPRT {
  * Service request
  */
 struct svc_req {
-	u_long		rq_prog;	/* service program number */
-	u_long		rq_vers;	/* service protocol version */
-	u_long		rq_proc;	/* the desired procedure */
-	struct opaque_auth rq_cred;	/* raw creds from the wire */
-	caddr_t		rq_clntcred;	/* read only cooked cred */
-	SVCXPRT	*rq_xprt;		/* associated transport */
+  rpcprog_t rq_prog;            /* service program number */
+  rpcvers_t rq_vers;            /* service protocol version */
+  rpcproc_t rq_proc;            /* the desired procedure */
+  struct opaque_auth rq_cred;   /* raw creds from the wire */
+  caddr_t rq_clntcred;          /* read only cooked cred */
+  SVCXPRT *rq_xprt;             /* associated transport */
 };
 
 #ifndef __DISPATCH_FN_T
@@ -165,23 +164,23 @@ typedef void (*__dispatch_fn_t) __PMT ((struct svc_req*, SVCXPRT*));
  *
  * svc_register(xprt, prog, vers, dispatch, protocol)
  *	SVCXPRT *xprt;
- *	u_long prog;
- *	u_long vers;
+ *	rpcprog_t prog;
+ *	rpcvers_t vers;
  *	void (*dispatch)();
  *	u_long protocol;  like TCP or UDP, zero means do not register
  */
-extern bool_t	svc_register __P ((SVCXPRT *__xprt, u_long __prog,
-				   u_long __vers, __dispatch_fn_t __dispatch,
-				   u_long __protocol));
+extern bool_t svc_register __P ((SVCXPRT *__xprt, rpcprog_t __prog,
+				 rpcvers_t __vers, __dispatch_fn_t __dispatch,
+				 rpcprot_t __protocol));
 
 /*
  * Service un-registration
  *
  * svc_unregister(prog, vers)
- *	u_long prog;
- *	u_long vers;
+ *	rpcprog_t prog;
+ *	rpcvers_t vers;
  */
-extern void	svc_unregister __P ((u_long __prog, u_long __vers));
+extern void svc_unregister __P ((rpcprog_t __prog, rpcvers_t __vers));
 
 /*
  * Transport registration.
@@ -189,7 +188,7 @@ extern void	svc_unregister __P ((u_long __prog, u_long __vers));
  * xprt_register(xprt)
  *	SVCXPRT *xprt;
  */
-extern void	xprt_register __P ((SVCXPRT *__xprt));
+extern void xprt_register __P ((SVCXPRT *__xprt));
 
 /*
  * Transport un-register
@@ -197,9 +196,7 @@ extern void	xprt_register __P ((SVCXPRT *__xprt));
  * xprt_unregister(xprt)
  *	SVCXPRT *xprt;
  */
-extern void	xprt_unregister __P ((SVCXPRT *__xprt));
-
-
+extern void xprt_unregister __P ((SVCXPRT *__xprt));
 
 
 /*
@@ -237,8 +234,8 @@ extern void	svcerr_weakauth __P ((SVCXPRT *__xprt));
 
 extern void	svcerr_noproc __P ((SVCXPRT *__xprt));
 
-extern void	svcerr_progvers __P ((SVCXPRT *__xprt, u_long __low_vers,
-				      u_long __high_vers));
+extern void	svcerr_progvers __P ((SVCXPRT *__xprt, rpcvers_t __low_vers,
+				      rpcvers_t __high_vers));
 
 extern void	svcerr_auth __P ((SVCXPRT *__xprt, enum auth_stat __why));
 
@@ -261,19 +258,20 @@ extern void	svcerr_systemerr __P ((SVCXPRT *__xprt));
  * Global keeper of rpc service descriptors in use
  * dynamic; must be inspected before each call to select
  */
-#ifdef FD_SETSIZE
+
+extern struct pollfd *svc_pollfd;
+extern int svc_max_pollfd;
 extern fd_set svc_fdset;
 #define svc_fds svc_fdset.fds_bits[0]	/* compatibility */
-#else
-extern int svc_fds;
-#endif /* def FD_SETSIZE */
 
 /*
  * a small program implemented by the svc_rpc implementation itself;
  * also see clnt.h for protocol numbers.
  */
 extern void svc_getreq __P ((int __rdfds));
+extern void svc_getreq_common __P ((const int __fd));
 extern void svc_getreqset __P ((fd_set *__readfds));
+extern void svc_getreq_poll __P ((struct pollfd *, const int));
 extern void svc_exit __P ((void));
 extern void svc_run __P ((void));
 
@@ -165,23 +164,23 @@ typedef void (*__dispatch_fn_t) __PMT ((struct svc_req*, SVCXPRT*));
  *	void (*dispatch)();
- *	u_long protocol;  like TCP or UDP, zero means do not register
+ *	rpcprot_t protocol;  like TCP or UDP, zero means do not register
  */